"""Docstring for snowdrift.config."""


def hello(x: int) -> str:
    """Sample hello function to test that the module is working correctly."""
    return f'Hello from config! The answer is {x}!'


def answer() -> int:
    """Sample answer function to test that the module is working correctly."""
    return 42
